@@ -5,17 +5,22 @@
 #
 ##############################################################################
 
-from ._version import __version__
+import txaio
+txaio.use_twisted()
+
+from ._version import __version__  # noqa
 from .common import address, uint256, unpack_uint256, pack_uint256,\
-    uint128, unpack_uint128, pack_uint128
-from . import schema, meta, xbr, xbrnetwork
+    uint128, unpack_uint128, pack_uint128  # noqa
+from . import meta, mrealm, xbr, xbrmm, xbrnetwork  # noqa
+from . import schema, globalschema, mrealmschema  # noqa
 
 __all__ = (
     '__version__',
     'meta',
+    'mrealm',
     'xbr',
+    'xbrmm',
     'xbrnetwork',
-    'schema',
     'address',
     'uint256',
     'pack_uint256',
@@ -23,4 +28,7 @@ __all__ = (
     'uint128',
     'pack_uint128',
     'unpack_uint128',
+    'schema',
+    'globalschema',
+    'mrealmschema',
 )
