@@ -10,17 +10,17 @@ from .api import Apis, IndexApiByCatalog
 from .block import Blocks
 from .catalog import Catalogs, IndexCatalogsByOwner
 
-from .consent import Consents, IndexConsentByMemberAddress
+from cfxdb.xbr.consent import Consents, IndexConsentByMemberAddress
 
-from .channel import PaymentChannels, IndexPaymentChannelByDelegate, \
-    PaymentChannelBalances, PayingChannels, IndexPayingChannelByDelegate, \
-    PayingChannelBalances
+from cfxdb.xbrmm.channel import PaymentChannels, IndexPaymentChannelByDelegate, \
+    IndexPaymentChannelByActor, PaymentChannelBalances, PayingChannels, IndexPayingChannelByDelegate, \
+    IndexPayingChannelByRecipient, PayingChannelBalances
 
 from .market import Markets, IndexMarketsByOwner, IndexMarketsByActor
 from .member import Members
-from .offer import Offers, IndexOfferByKey
+from cfxdb.xbrmm.offer import Offers, IndexOfferByKey
 from .token import TokenApprovals, TokenTransfers
-from .transaction import Transactions
+from cfxdb.xbrmm.transaction import Transactions
 
 
 class Schema(object):
@@ -111,6 +111,12 @@ class Schema(object):
     channel address for the given consumer delegate.
     """
 
+    idx_payment_channel_by_actor: IndexPaymentChannelByActor
+    """
+    Maps from XBR (buyer) actor address to the currently active payment
+    channel address for the given actor.
+    """
+
     payment_balances: PaymentChannelBalances
     """
     Current off-chain balances within payment channels.
@@ -127,6 +133,12 @@ class Schema(object):
     channel address for the given provider delegate.
     """
 
+    idx_paying_channel_by_recipient: IndexPayingChannelByRecipient
+    """
+    Maps from XBR seller actor address to the currently active paying
+    channel address for the given actor.
+    """
+
     paying_balances: PayingChannelBalances
     """
     Current off-chain balances within paying channels.
@@ -169,6 +181,9 @@ class Schema(object):
 
         schema.idx_catalogs_by_owner = db.attach_table(IndexCatalogsByOwner)
 
+        schema.catalogs.attach_index('idx1', schema.idx_catalogs_by_owner, lambda catalog:
+                                     (catalog.owner, catalog.timestamp))
+
         schema.consents = db.attach_table(Consents)
 
         schema.idx_consent_by_member_adr = db.attach_table(IndexConsentByMemberAddress)
@@ -195,23 +210,28 @@ class Schema(object):
         schema.payment_channels = db.attach_table(PaymentChannels)
 
         schema.idx_payment_channel_by_delegate = db.attach_table(IndexPaymentChannelByDelegate)
-        # schema.payment_channels.attach_index('idx1',
-        #                                      schema.idx_payment_channel_by_delegate,
-        #                                      lambda payment_channel: (bytes(payment_channel.delegate), np.datetime64(time_ns(), 'ns')))
+        schema.payment_channels.attach_index(
+            'idx1', schema.idx_payment_channel_by_delegate, lambda payment_channel:
+            (bytes(payment_channel.delegate), payment_channel.timestamp))
+
+        schema.idx_payment_channel_by_actor = db.attach_table(IndexPaymentChannelByActor)
+        schema.payment_channels.attach_index(
+            'idx2', schema.idx_payment_channel_by_actor, lambda payment_channel:
+            (bytes(payment_channel.actor), payment_channel.timestamp))
 
         schema.payment_balances = db.attach_table(PaymentChannelBalances)
 
         schema.paying_channels = db.attach_table(PayingChannels)
 
         schema.idx_paying_channel_by_delegate = db.attach_table(IndexPayingChannelByDelegate)
-        # schema.paying_channels.attach_index('idx1',
-        #                                      schema.idx_paying_channel_by_delegate,
-        #                                      lambda paying_channel: (bytes(paying_channel.delegate), np.datetime64(time_ns(), 'ns')))
+        schema.paying_channels.attach_index(
+            'idx1', schema.idx_paying_channel_by_delegate, lambda paying_channel:
+            (bytes(paying_channel.delegate), paying_channel.timestamp))
 
-        # schema.idx_paying_channel_by_recipient = db.attach_table(IndexPayingChannelByRecipient)
-        # schema.paying_channels.attach_index('idx2',
-        #                                      schema.idx_paying_channel_by_recipient,
-        #                                      lambda paying_channel: (bytes(paying_channel.recipient), np.datetime64(time_ns(), 'ns')))
+        schema.idx_paying_channel_by_recipient = db.attach_table(IndexPayingChannelByRecipient)
+        schema.paying_channels.attach_index(
+            'idx2', schema.idx_paying_channel_by_recipient, lambda paying_channel:
+            (bytes(paying_channel.recipient), paying_channel.timestamp))
 
         schema.paying_balances = db.attach_table(PayingChannelBalances)
 
